@@ -50,6 +50,18 @@ class c获取索引项目:
         return f'{self.变量}[{toCString(self.索引)}]'
 
 
+class c获取属性:
+    def __init__(self, 变量, 属性) -> None:
+        self.变量 = 变量
+        self.属性 = 属性
+
+    def __str__(self) -> str:
+        if isinstance(self.变量, c变量):
+            if self.变量.类型.endswith('*'):
+                return f'{self.变量}->{self.属性}'
+        return f'{self.变量}.{self.属性}'
+
+
 class py2cpp编译器(ast.NodeVisitor):
     def __init__(self, 被编译的函数: Callable) -> None:
         self.被编译的函数 = 被编译的函数
@@ -144,7 +156,7 @@ class py2cpp编译器(ast.NodeVisitor):
         if isinstance(value, ast.Attribute):
             对象 = self.获取值(value.value)
             if isinstance(对象, c变量):
-                return f'{对象}.{value.attr}'
+                return c获取属性(对象, value.attr)
             if 对象 is None:
                 self.抛出代码异常(f'没找到{value.value}', value)
             return getattr(对象, value.attr)
